/*! \file
 *  \brief Заголовочный файл со вспомогательными функциями
 */

#ifndef COMMON_H
#define COMMON_H

/*!
 *  \fn void create_spectrum(float *dst, const int size, const int freq, const float amplitude)
 *  \brief Генерация входного сигнала типа float
 *  \param[out] dst выходные данные типа float
 *  \param[in] size размер сигнала
 *  \param[in] freq частота сигнала
 *  \param[in] amplitude амплитуда сигнала
 */
void create_spectrum(float *dst, const int size, const int freq, const float amplitude);
/*!
 *  \fn bool maximum_norm(const float *dsp_res, const float *ref_res, const int size)
 *  \brief Сравнение векторов типа float
 *  \param[in] dsp_res входные данные типа float
 *  \param[in] ref_res входные данные типа float
 *  \param[in] size размер входных данных
 *  \return
 *      - \b float максимум-норма
 */
float maximum_norm(const float *dsp_res, const float *ref_res, const int size);

float maximum_norm_conv2d(const float *dsp_res, const float *ref_res, const int rows, const int cols);
/*!
 *  \fn void print_vector(float *src, const int size)
 *  \brief Печать вектора типа float
 *  \param[in] src входные данные типа float
 *  \param[in] size размер входных данных
 */
void print_vector(float *src, const int size);
/*!
 *  \fn void print_vector_to_file(float *src, const int size, char path[])
 *  \brief Печать вектора типа float
 *  \param[in] src входные данные типа float
 *  \param[in] size размер входных данных
 *  \param[in] path путь для печати вектора
 */
void print_vector_to_file(float *src, const int size, char path[]);
/*!
 *  \fn void create_spectrum_2d(float *dst, const int height, const int length, const int freq1, const int freq2, const DataTypes fft_type)
 *  \brief Генерация двумерного входного сигнала
 *  \param[out] dst выходные данные типа float
 *  \param[in] height высота входных данных
 *  \param[in] length ширина входных данных
 *  \param[in] freq1 частота по высоте
 *  \param[in] freq2 частота по ширине
 *  \param[in] fft_type тип данных преобразования
 */
void create_spectrum_2d(float *dst, const int height, const int length, const int freq1,
                        const int freq2, const int data_type);


#endif
